==> percentdict-0.1.tar.gz: percentdict-0.1/setup.py <==
from distutils.core import setup

setup(
  name = 'percentdict',         # How you named your package folder (MyLib)
  packages = ['percentdict'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'percent and ranged dict like dictionaries to get info with a value in a range',   # Give a short description about your library
  author = 'Ivan Uría',                   # Type in your name
  author_email = 'ivan.uria@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/ivanuria/percentdict',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/ivanuria/percentdict/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['DICT', 'RANGE', 'VALUE'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.3',  #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8', 
    'Programming Language :: Python :: 3.9',
  ],
)

==> percentdict-0.1.1.tar.gz: percentdict-0.1.1/setup.py <==
from distutils.core import setup

setup(
  name = 'percentdict',         # How you named your package folder (MyLib)
  packages = ['percentdict'],   # Chose the same as "name"
  version = '0.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'percent and ranged dict like dictionaries to get info with a value in a range',   # Give a short description about your library
  author = 'Ivan Uría',                   # Type in your name
  author_email = 'ivan.uria@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/ivanuria/percentdict',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/ivanuria/percentdict/archive/v_01.01.tar.gz',    # I explain this later on
  keywords = ['DICT', 'RANGE', 'VALUE'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.3',  #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8', 
    'Programming Language :: Python :: 3.9',
  ],
)
